@@ -1,6 +1,6 @@
 import time
 
-from lettuce import step, world
+from lettuce import step
 
 
 @step(r'look around')
@@ -10,9 +10,9 @@ def look_around(step):
 
 @step(r'wait (\d+) seconds?')
 def wait(step, seconds):
-    time.sleep(int(seconds))
+    time.sleep(float(seconds))
 
 
-@step(r'Then I should fail because "(.*)"')
+@step(r'should fail because "(.*)"')
 def should_fail(step, because):
     assert because == True
